<template>
  <el-dialog
    title="选择物资信息"
    :visible.sync="showDia"
    :append-to-body="false"
    :modal-append-to-body="false"
    :close-on-click-modal="false"
    width="85%"
    :show-close="true"
    :before-close="handleClose"
    top="5vh"
    style="min-height: 700px;"
  >
    <div class="tree-table-container">
      <el-row class="fullheight">
        <el-col :span="4" class="fullheight">
          <div class="common-tree-container">
            <div class="common-tree-title">
              <i class="el-icon-menu" /> 物资分类目录
            </div>
            <div class="common-tree-content">
              <el-tree
                v-if="treeData.length"
                highlight-current
                :data="treeData"
                :props="defaultProps"
                default-expand-all
                @node-click="handleNodeClick"
              />
            </div>
          </div>
        </el-col>
        <el-col :span="20" class="fullheight">
          <div class="common-table-container">
            <div class="bbsl-common-page">
              <div class="bbsl-table-search">
                <el-form v-model="queryParam" :inline="true">
                  <el-row :gutter="10">
                    <el-col :span="6.5">
                      <el-form-item label="品名">
                        <el-input
                          v-model="querys[0].value"
                          clearable
                          placeholder="请输入品名"
                        />
                      </el-form-item>
                    </el-col>
                    <!-- <el-col :span="6.5">
	                    <el-form-item label="所属仓库">

	  					  <el-select
	  					    clearable
	  					    style="width:100%"
	  					    v-model="querys[1].value"
	  					    placeholder="请选择仓库"
	  					  >
	  					    <el-option
	  					      v-for="item in warehouses"
	  					      :key="item.value"
	  					      :label="item.name"
	  					      :value="item.value"
	  					    ></el-option>
	  					  </el-select>
	                    </el-form-item>
	                  </el-col> -->
                    <!-- <el-col :span="6.5">
	  				    <el-form-item label="厂商">
	  				      <el-input
	  				        clearable
	  				        placeholder="请输入厂商"
	  				        v-model="querys[2].value"
	  				      ></el-input>
	  				    </el-form-item>
	  				  </el-col> -->
                    <el-col :span="4">
                      <el-form-item>
                        <el-button
                          type="primary"
                          icon="el-icon-search"
                          @click="handleSearch"
                        >搜索
                        </el-button
                        >
                        <el-button icon="el-icon-refresh" @click="handleReset"
                        >重置
                        </el-button
                        >
                      </el-form-item>
                    </el-col>
                  </el-row>
                </el-form>
              </div>
              <div ref="contentPanel" class="bbsl-table-content">
                <el-table
                  ref="multipleSelection"
                  v-loading="loading"
                  border
                  size="mini"
                  :data="tableData"
                  :style="{width: '100%'}"
                  :max-height="tableMaxHeight"
                  :cell-style="{'text-align': 'center'}"
                  :header-cell-style="{'text-align': 'center'}"
                  @selection-change="handleSelectChange"
                >
                  <el-table-column
                    type="selection"
                    width="55"
                    :selectable="checkSelectable"
                  />
                  <el-table-column fixed type="index" width="55" label="序号" />
                  <el-table-column
                    sortable
                    prop="warehouse"
                    label="所属仓库"
                    show-overflow-tooltip
                    :formatter="formartWarehouseName"
                  />
                  <el-table-column
                    sortable
                    prop="cmgtMaterialInfo.name"
                    label="品名"
                    show-overflow-tooltip
                  />
                  <el-table-column
                    sortable
                    prop="cmgtMaterialInfo.code"
                    label="编号"
                    show-overflow-tooltip
                  />
                  <el-table-column
                    sortable
                    prop="cmgtMaterialInfo.model"
                    label="规格型号"
                    show-overflow-tooltip
                  />
                  <el-table-column
                    sortable
                    prop="cmgtMaterialInfo.unit"
                    width="90"
                    label="单位"
                    show-overflow-tooltip
                  />
                  <el-table-column
                    sortable
                    prop="quantity"
                    label="库存数量"
                    show-overflow-tooltip
                  />
                  <!-- <el-table-column
	                  sortable
	                  prop="code"
	                  label="编号"
	                  show-overflow-tooltip
	                >
	                </el-table-column> -->

                  <!--  <el-table-column
	                  sortable
	                  prop="model"
	                  label="型号"
	                  show-overflow-tooltip
	                ></el-table-column> -->
                  <!-- <el-table-column
	                  sortable
	                  prop="manufacturer"
	                  label="厂商"
	                  show-overflow-tooltip
	                ></el-table-column> -->
                </el-table>
                <el-pagination
                  ref="paginationPanel"
                  align="right"
                  background
                  :current-page="queryParam.pageBean.page"
                  :page-sizes="[20, 30, 40, 50]"
                  :page-size="queryParam.pageBean.pageSize"
                  layout="total, sizes, prev, pager, next, jumper"
                  :total="total"
                  @size-change="handleSizeChange"
                  @current-change="handleCurrentChange"
                />
              </div>
            </div>
          </div>
        </el-col>
      </el-row>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button type="primary" @click="saveMaterial">确认添加</el-button>
      <el-button type="infor" @click="handleClose">取 消</el-button>
    </div>
  </el-dialog>
</template>

<script>
import quantityManage from '@/views/Manage/material/api/materialQuantityManage.js'
import {TableMixin} from '@/mixins/tableMixin'
import dictContracts from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'QuantityMaterialManage',
  components: {},
  mixins: [TableMixin],
  data() {
    return {
      titles: '',
      tableData: [],
      showDia: false,
      treeData: [
        {code: '0', id: 0, typeName: '物资分类信息', parentId: 0, children: []}
      ],
      defaultProps: {
        value: 'id',
        label: 'typeName',
        parentId: 'parentId',
        code: 'code',
        children: 'children'
      },
      data: [],
      treeNode: {
        code: '0',
        id: 0,
        typeName: '物资分类信息',
        parentId: 0,
        children: []
      },
      updateTreeNode: null,
      url: {},
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'warehouse_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'manufacturer_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'class_Id_',
          relation: 'AND',
          value: ''
        }
      ],
      warehouses: [],
      materialSelection: []
    }
  },
  watch: {
    filterText(val) {
      console.log(val)
      this.$refs.tree.filter(val)
    }
  },
  created() {
    this.warehouses = dictContracts.getDictItemsFromCache('cmgt_ckmc')
  },
  mounted() {
    this.getTreen()
  },
  methods: {
    // 树查询
    getTreen() {
      quantityManage.loadAllClass({}, res => {
        this.treeData[0].children = res
        this.$set(this.treeData)
      })
    },
    reload() {
      this.treeData = [
        {code: '', id: 0, typeName: '物资管理', parentId: 0, children: []}
      ]
      this.$set(this.treeData)
      this.getTreen()
      // this.loadData()
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 分页查询物资信息
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      quantityManage.materialQuantityQuery(this.queryParam).then(res => {
        // console.log(res)
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleNodeClick(data) {
      // 点击分类树节点
      this.treeNode = data
      if (data.id == '0') {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      } else {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      }
    },
    formartWarehouseName(row, column, cellValue, index) {
      var obj = this.warehouses.find(function(item) {
        if (item.value === row.warehouse) {
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    },
    handleSelectChange(val) {
      this.materialSelection = val
    },
    handleClose() {
      this.materialSelection = []
      this.$refs.multipleSelection.clearSelection()
      // done()
      this.showDia = false
    },
    saveMaterial() {
      // 获取选中数据
      var materials = []
      this.materialSelection.forEach(r => {
        materials.push({
          quantity: 0,
          availableQuantity: r.quantity,
          name: r.cmgtMaterialInfo.name,
          memo: '',
          id: null,
          price: 0,
          amount: 0,
          warehouseInoutId: null,
          materialInfoId: r.mid,
          supplier: '',
          unit: r.cmgtMaterialInfo.unit,
          model: r.cmgtMaterialInfo.model,
          description: r.id // 库存id
        })
      })
      this.$emit('saveSelectMaterial', materials)
      this.$refs.multipleSelection.clearSelection()
      // this.showDia = false
    },
    checkSelectable(row) {
      return row.quantity > 0
    }
  }
}
</script>
<style lang="scss" scoped>
.common-tree-container ::v-deep .el-tree {
  border: none;
}
</style>
